# SMHI Swedish weather institute package
Python library for accessing SMHI open forecast data

Please visit http://opendata.smhi.se/apidocs/metfcst/parameters.html for more information

If you want to contribute you can use devcontainers in vscode for easiest setup. Please see [instructions here](.devcontainer/README.md)


If you like what I do and want to buy me a cup of coffee. It is always appreciated :)

<a href="https://www.buymeacoffee.com/ij1qXRM6E" target="_blank"><img src="https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>